Learn R Programming

riboSeqR (version 1.6.0)

frameCounting: Counts aligned reads within coding sequence regions by frame and footprint size, splitting by frame and footprint size.

Description

Ribosome footprint sequencing reads aligning within coding sequence regions may align in the same frame (relative to start codon) as the coding sequence, or frame shifted by 1 or 2 frames. This function calls the number of aligning reads within the coding sequence, split by frame and footprint size.

Usage

frameCounting(riboDat, fastaCDS, lengths = 25:30)

Arguments

riboDat
A riboData object containing the ribosome footprints to be counted.
fastaCDS
A GenomicRanges object containing the coordinates of the coding sequences.
lengths
Lengths of ribosome footprints to be included in the riboData object.

Value

A riboCoding object.

See Also

riboData

Examples

Run this code

#ribosomal footprint data
datadir <- system.file("extdata", package = "riboSeqR")
ribofiles <- paste(datadir, 
                   "/chlamy236_plus_deNovo_plusOnly_Index", c(17,3,5,7), sep = "")
rnafiles <- paste(datadir, 
                  "/chlamy236_plus_deNovo_plusOnly_Index", c(10,12,14,16), sep = "")

riboDat <- readRibodata(ribofiles, rnafiles, replicates = c("WT", "WT",
"M", "M"))

# CDS coordinates
chlamyFasta <- paste(datadir, "/rsem_chlamy236_deNovo.transcripts.fa", sep = "")
fastaCDS <- findCDS(fastaFile = chlamyFasta, 
                    startCodon = c("ATG"), 
                    stopCodon = c("TAG", "TAA", "TGA"))

# frame calling
fCs <- frameCounting(riboDat, fastaCDS)


Run the code above in your browser using DataLab